@@ -9,7 +9,7 @@ from pca.pca import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.8.2'
+__version__ = '1.8.4'
 
 # module level doc-string
 __doc__ = """
@@ -54,7 +54,8 @@ Examples
 
 References
 ----------
-* https://github.com/erdogant/pca
-* https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.SparsePCA.html
+* Blog: https://towardsdatascience.com/what-are-pca-loadings-and-biplots-9a7897f2e559
+* Github: https://github.com/erdogant/pca
+* Documentation: https://erdogant.github.io/pca/
 
 """
