@@ -14,52 +14,55 @@ import numpy as np
 import matplotlib.pyplot as plt
 import os
 import wget
+from adjustText import adjust_text
 
 
 # %% Association learning across all variables
 class pca():
-    """pca module."""
+    """pca module.
+
+    Parameters
+    ----------
+    n_components : [0..1] or [1..number of samples-1], (default: 0.95)
+        Number of PCs to be returned. When n_components is set >0, the specified number of PCs is returned.
+        When n_components is set between [0..1], the number of PCs is returned that covers at least this percentage of variance.
+        n_components=None : Return all PCs
+        n_components=0.95 : Return the number of PCs that cover at least 95% of variance.
+        n_components=3    : Return the top 3 PCs.
+    n_feat : int, default: 10
+        Number of features that explain the space the most, dervied from the loadings. This parameter is used for vizualization purposes only.
+    method : 'pca' (default)
+        'pca' : Principal Component Analysis.
+        'sparse_pca' : Sparse Principal Components Analysis.
+        'trunc_svd' : truncated SVD (aka LSA).
+    alpha : float, default: 0.05
+        Alpha to set the threshold to determine the outliers based on on the Hoteling T2 test.
+    n_std : int, default: 2
+        Number of standard deviations to determine the outliers using SPE/DmodX method.
+    onehot : [Bool] optional, (default: False)
+        Boolean: Set True if X is a sparse data set such as the output of a tfidf model. Many zeros and few numbers.
+        Note this is different then a sparse matrix. In case of a sparse matrix, use method='trunc_svd'.
+    normalize : bool (default : False)
+        Normalize data, Z-score
+    detect_outliers : list (default : ['ht2','spe'])
+        None: Do not compute outliers.
+        'ht2': compute outliers based on Hotelling T2.
+        'spe': compute outliers basedon SPE/DmodX method.
+    random_state : int optional
+        Random state
+    Verbose : int (default : 3)
+        Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
+
+    References
+    ----------
+    * Blog: https://towardsdatascience.com/what-are-pca-loadings-and-biplots-9a7897f2e559
+    * Github: https://github.com/erdogant/pca
+    * Documentation: https://erdogant.github.io/pca/
+
+    """
 
     def __init__(self, n_components=0.95, n_feat=25, method='pca', alpha=0.05, n_std=2, onehot=False, normalize=False, detect_outliers=['ht2', 'spe'], random_state=None, verbose=3):
-        """Initialize pca with user-defined parameters.
-
-        Parameters
-        ----------
-        n_components : [0,..,1] or [1,..number of samples-1], (default: 0.95)
-            Number of TOP components to be returned. Values>0 are the number of components. Values<0 are the components that covers at least the percentage of variance.
-            None: Take all components
-            0.95: Take the number of components that cover at least 95% of variance.
-            k: Take the top k components
-        n_feat : int, default: 10
-            Number of features that explain the space the most, dervied from the loadings. This parameter is used for vizualization purposes only.
-        method : 'pca' (default)
-            'pca' : Principal Component Analysis.
-            'sparse_pca' : Sparse Principal Components Analysis.
-            'trunc_svd' : truncated SVD (aka LSA).
-        alpha : float, default: 0.05
-            Alpha to set the threshold to determine the outliers based on on the Hoteling T2 test.
-        n_std : int, default: 2
-            Number of standard deviations to determine the outliers using SPE/DmodX method.
-        onehot : [Bool] optional, (default: False)
-            Boolean: Set True if X is a sparse data set such as the output of a tfidf model. Many zeros and few numbers.
-            Note this is different then a sparse matrix. In case of a sparse matrix, use method='trunc_svd'.
-        normalize : bool (default : False)
-            Normalize data, Z-score
-        detect_outliers : list (default : ['ht2','spe'])
-            None: Do not compute outliers.
-            'ht2': compute outliers based on Hotelling T2.
-            'spe': compute outliers basedon SPE/DmodX method.
-        random_state : int optional
-            Random state
-        Verbose : int (default : 3)
-            Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
-
-        References
-        ----------
-            * https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.SparsePCA.html
-            * https://scikit-learn.org/stable/modules/generated/sklearn.decomposition.TruncatedSVD.html
-
-        """
+        """Initialize pca with user-defined parameters."""
         if isinstance(detect_outliers, str): detect_outliers = [detect_outliers]
         if onehot:
             if verbose>=3: print('[pca] >Method is set to: [sparse_pca] because onehot=True.')
@@ -262,7 +265,7 @@ class pca():
         # Store
         self.results = _store(PC, loadings, percentExplVar, model_pca, self.n_components, pcp, col_labels, row_labels, topfeat, outliers, scaler, outliers_params)
         # Return
-        return(self.results)
+        return self.results
 
     def _clean(self, verbose=3):
         # Clean readily fitted models to ensure correct results.
@@ -287,7 +290,7 @@ class pca():
         -------
         outliers : numpy array
             Array containing outliers.
-        outliers_params: dictionary, (default: None)
+        outliers_params: dict, (default: None)
             Contains parameters for hotellingsT2() and spe_dmodx(), reusable in the future.
         """
         # Convert to numpy array if required
@@ -487,7 +490,21 @@ class pca():
         return y, topfeat, n_feat
 
     # Scatter plot
-    def scatter3d(self, y=None, label=True, PC=[0, 1, 2], legend=True, SPE=False, hotellingt2=False, cmap='Set1', visible=True, figsize=(15, 10), alpha_transparency=None, title=None, gradient=None):
+    def scatter3d(self,
+                  y=None,
+                  label=True,
+                  PC=[0, 1, 2],
+                  SPE=False,
+                  hotellingt2=False,
+                  alpha_transparency=None,
+                  gradient=None,
+                  fontdict={'weight': 'normal', 'size': 12, 'ha': 'center', 'va': 'center'},
+                  cmap='Set1',
+                  title=None,
+                  legend=True,
+                  figsize=(15, 10),
+                  visible=True,
+                  verbose=3):
         """Scatter 3d plot.
 
         Parameters
@@ -500,25 +517,30 @@ class pca():
             None: Ignore all labels (this will significanly speed up the scatterplot)
         PC : list, default : [0, 1, 2]
             Plot the first three Principal Components. Note that counting starts from 0. PC1=0, PC2=1, PC3=2, etc
-        legend : Bool, default: True
-            Show the legend based on the unique y-labels.
         SPE : Bool, default: False
             Show the outliers based on SPE/DmodX method.
         hotellingt2 : Bool, default: False
             Show the outliers based on the hotelling T2 test.
-        cmap : String, optional, default: 'Set1'
-            Colormap. If set to None, no points are shown.
-        visible : Bool, default: True
-            Visible status of the Figure. When False, figure is created on the background.
-        figsize : (int, int), optional, default: (15, 10)
-            (width, height) in inches.
         alpha_transparency : Float, default: None
             The alpha blending value, between 0 (transparent) and 1 (opaque).
-        title : str, default: None
-            Title of the figure.
         gradient : String, (default: None)
             Hex (ending) color for the gradient of the scatterplot colors.
             '#FFFFFF'
+        fontdict : dict.
+            dictionary containing properties for the arrow font-text
+            {'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'}
+        cmap : String, optional, default: 'Set1'
+            Colormap. If set to None, no points are shown.
+        title : str, default: None
+            Title of the figure.
+        legend : Bool, default: True
+            Show the legend based on the unique y-labels.
+        figsize : (int, int), optional, default: (15, 10)
+            (width, height) in inches.
+        visible : Bool, default: True
+            Visible status of the Figure. When False, figure is created on the background.
+        Verbose : int (default : 3)
+            Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
 
         Returns
         -------
@@ -526,14 +548,43 @@ class pca():
 
         """
         if self.results['PC'].shape[1]>=3:
-            fig, ax = self.scatter(y=y, d3=True, label=label, legend=legend, PC=PC, SPE=SPE, hotellingt2=hotellingt2, cmap=cmap, visible=visible, figsize=figsize, alpha_transparency=alpha_transparency, title=title, gradient=gradient)
+            fig, ax = self.scatter(y=y,
+                                   d3=True,
+                                   label=label,
+                                   PC=PC, SPE=SPE,
+                                   hotellingt2=hotellingt2,
+                                   alpha_transparency=alpha_transparency,
+                                   gradient=gradient,
+                                   fontdict=fontdict,
+                                   cmap=cmap,
+                                   title=title,
+                                   legend=legend,
+                                   figsize=figsize,
+                                   visible=visible,
+                                   verbose=verbose)
         else:
             print('[pca] >Error: There are not enough PCs to make a 3d-plot.')
             fig, ax = None, None
         return fig, ax
 
     # Scatter plot
-    def scatter(self, y=None, d3=False, label=True, PC=[0, 1], legend=True, SPE=False, hotellingt2=False, cmap='Set1', visible=True, figsize=(20, 15), alpha_transparency=None, title=None, gradient=None, verbose=3):
+    def scatter(self,
+                y=None,
+                s=50,
+                d3=False,
+                label=True,
+                PC=[0, 1],
+                SPE=False,
+                hotellingt2=False,
+                alpha_transparency=None,
+                gradient=None,
+                fontdict={'weight': 'normal', 'size': 12, 'ha': 'center', 'va': 'center'},
+                cmap='Set1',
+                title=None,
+                legend=True,
+                figsize=(20, 15),
+                visible=True,
+                verbose=3):
         """Scatter 2d plot.
 
         Parameters
@@ -548,25 +599,28 @@ class pca():
             None: Ignore all labels (this will significanly speed up the scatterplot)
         PC : list, default : [0, 1]
             Plot the first two Principal Components. Note that counting starts from 0. PC1=0, PC2=1, PC3=2, etc
-        legend : Bool, default: True
-            Show the legend based on the unique y-labels.
         SPE : Bool, default: False
             Show the outliers based on SPE/DmodX method.
         hotellingt2 : Bool, default: False
             Show the outliers based on the hotelling T2 test.
-        cmap : String, optional, default: 'Set1'
-            Colormap. If set to None, no points are shown.
-        visible : Bool, default: True
-            Visible status of the Figure. When False, figure is created on the background.
-        figsize : (int, int), optional, default: (15, 10)
-            (width, height) in inches.
         alpha_transparency : Float, default: None
             The alpha blending value, between 0 (transparent) and 1 (opaque).
-        title : str, (default: None)
-            Title of the figure.
         gradient : String, (default: None)
             Hex color to make a lineair gradient for the scatterplot.
             '#FFFFFF'
+        fontdict : dict.
+            dictionary containing properties for the arrow font-text
+            {'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'}
+        cmap : String, optional, default: 'Set1'
+            Colormap. If set to None, no points are shown.
+        title : str, (default: None)
+            Title of the figure.
+        legend : Bool, default: True
+            Show the legend based on the unique y-labels.
+        figsize : (int, int), optional, default: (15, 10)
+            (width, height) in inches.
+        visible : Bool, default: True
+            Visible status of the Figure. When False, figure is created on the background.
         Verbose : int (default : 3)
             Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
 
@@ -576,6 +630,8 @@ class pca():
 
         """
         if (gradient is not None) and ((not isinstance(gradient, str)) or (len(gradient)!=7)): raise Exception('[pca]> Error: gradient must be of type string with Hex color or None.')
+        fontdict = {**{'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'}, **fontdict}
+        # Setup figure
         fig = plt.figure(figsize=figsize)
         if d3:
             ax = fig.add_subplot(projection='3d')
@@ -612,7 +668,7 @@ class pca():
                 if g_ellipse is not None: ax.add_artist(g_ellipse)
 
         # Make scatter plot of all not-outliers
-        Inormal = ~np.logical_or(Ioutlier1, Ioutlier2)
+        # Inormal = ~np.logical_or(Ioutlier1, Ioutlier2)
         uiy = np.unique(y)
 
         if (len(uiy)==len(y)) and (len(uiy)>=1000) and (label is not None):
@@ -620,9 +676,9 @@ class pca():
         # Add the labels
         if (label is None):
             if d3:
-                ax.scatter(xs, ys, zs, s=50, alpha=alpha_transparency, color=getcolors, label=None)
+                ax.scatter(xs, ys, zs, s=s, alpha=alpha_transparency, color=getcolors, label=None)
             else:
-                ax.scatter(xs, ys, s=50, alpha=alpha_transparency, color=getcolors, label=None)
+                ax.scatter(xs, ys, s=s, alpha=alpha_transparency, color=getcolors, label=None)
         else:
             for yk in uiy:
                 Iloc_sampl = (yk==y)
@@ -631,11 +687,12 @@ class pca():
                 # if yk=='mapped': Iloc_sampl[y=='mapped']=True
 
                 if d3:
-                    ax.scatter(xs[Iloc_sampl], ys[Iloc_sampl], zs[Iloc_sampl], s=60, label=yk, alpha=alpha_transparency, color=getcolors[Iloc_sampl, :])
-                    if label: ax.text(np.mean(xs[Iloc_sampl]), np.mean(ys[Iloc_sampl]), np.mean(zs[Iloc_sampl]), str(yk), color=[0, 0, 0], fontdict={'weight': 'bold', 'size': 16})
+                    ax.scatter(xs[Iloc_sampl], ys[Iloc_sampl], zs[Iloc_sampl], s=s + 10, label=yk, alpha=alpha_transparency, color=getcolors[Iloc_sampl, :])
+                    if label: ax.text(np.mean(xs[Iloc_sampl]), np.mean(ys[Iloc_sampl]), np.mean(zs[Iloc_sampl]), str(yk), color=[0, 0, 0], fontdict=fontdict)
                 else:
-                    ax.scatter(xs[Iloc_sampl], ys[Iloc_sampl], s=60, label=yk, alpha=alpha_transparency, color=getcolors[Iloc_sampl, :])
-                    if label: ax.annotate(yk, (np.mean(xs[Iloc_sampl]), np.mean(ys[Iloc_sampl])))
+                    ax.scatter(xs[Iloc_sampl], ys[Iloc_sampl], s=s + 10, label=yk, alpha=alpha_transparency, color=getcolors[Iloc_sampl, :])
+                    if label: ax.text(np.mean(xs[Iloc_sampl]), np.mean(ys[Iloc_sampl]), str(yk), color=[0, 0, 0], fontdict=fontdict)
+                    # if label: ax.annotate(yk, np.mean(xs[Iloc_sampl]), np.mean(ys[Iloc_sampl]))
 
         # Plot outliers for hotelling T2 test.
         if SPE and ('y_bool_spe' in self.results['outliers'].columns):
@@ -673,7 +730,24 @@ class pca():
         # Return
         return (fig, ax)
 
-    def biplot(self, y=None, n_feat=None, d3=False, label=True, PC=[0, 1], legend=True, SPE=False, hotellingt2=False, cmap='Set1', figsize=(15, 10), visible=True, alpha_transparency=None, color_arrow='r', title=None, gradient=None, verbose=3):
+    def biplot(self,
+               y=None,
+               n_feat=None,
+               d3=False,
+               label=True,
+               PC=[0, 1],
+               SPE=False,
+               hotellingt2=False,
+               alpha_transparency=None,
+               gradient=None,
+               color_arrow='r',
+               fontdict={'weight': 'normal', 'size': 12, 'ha': 'center', 'va': 'center'},
+               cmap='Set1',
+               title=None,
+               legend=True,
+               figsize=(15, 10),
+               visible=True,
+               verbose=3):
         """Create the Biplot.
 
         Description
@@ -697,28 +771,34 @@ class pca():
             None: Ignore all labels (this will significanly speed up the scatterplot)
         PC : list, default : [0, 1]
             Plot the selected Principal Components. Note that counting starts from 0. PC1=0, PC2=1, PC3=2, etc.
-        legend : Bool, default: True
-            Show the legend based on the unique y-labels.
         SPE : Bool, default: False
             Show the outliers based on SPE/DmodX method.
         hotellingt2 : Bool, default: False
             Show the outliers based on the hotelling T2 test.
+        alpha_transparency : Float, default: None
+            The alpha blending value, between 0 (transparent) and 1 (opaque).
+        gradient : String, (default: None)
+            Hex (ending) color for the gradient of the scatterplot colors.
+            '#FFFFFF'
+        color_arrow : String, (default: 'r')
+            color for the arrow.
+            'r' (default)
+        fontdict : dict.
+            dictionary containing properties for the arrow font-text
+            {'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'}
         cmap : String, optional, default: 'Set1'
             Colormap. If set to None, no points are shown.
+        title : str, (default: None)
+            Title of the figure.
+        legend : Bool, default: True
+            Show the legend based on the unique y-labels.
         figsize : (int, int), optional, default: (15, 10)
             (width, height) in inches.
         visible : Bool, default: True
             Visible status of the Figure. When False, figure is created on the background.
-        alpha_transparency : Float, default: None
-            The alpha blending value, between 0 (transparent) and 1 (opaque).
         Verbose : int (default : 3)
             The higher the number, the more information is printed.
             Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
-        gradient : String, (default: None)
-            Hex (ending) color for the gradient of the scatterplot colors.
-            '#FFFFFF'
-        title : str, (default: None)
-            Title of the figure.
 
         Returns
         -------
@@ -726,8 +806,8 @@ class pca():
 
         References
         ----------
+            * https://towardsdatascience.com/what-are-pca-loadings-and-biplots-9a7897f2e559
             * https://stackoverflow.com/questions/50796024/feature-variable-importance-after-a-pca-analysis/50845697#50845697
-            * https://towardsdatascience.com/pca-clearly-explained-how-when-why-to-use-it-and-feature-importance-a-guide-in-python-7c274582c37e
 
         """
         if self.results['PC'].shape[1]<2: raise ValueError('[pca] >[Error] Requires 2 PCs to make 2d plot.')
@@ -738,6 +818,7 @@ class pca():
         elif verbose>=3:
             print('[pca] >Plot PC%.0d vs PC%.0d with loadings.' %(PC[0] + 1, PC[1] + 1))
         if cmap is False: cmap=None
+        fontdict = {**{'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'}, **fontdict}
 
         # Pre-processing
         y, topfeat, n_feat = self._fig_preprocessing(y, n_feat, d3)
@@ -745,7 +826,7 @@ class pca():
         topfeat.reset_index(inplace=True)
 
         # Collect coefficients
-        coeff = self.results['loadings'].iloc[0:n_feat, :]
+        coeff = self.results['loadings'].iloc[PC, :]
 
         # Use the PCs only for scaling purposes
         mean_x = np.mean(self.results['PC'].iloc[:, PC[0]].values)
@@ -775,28 +856,46 @@ class pca():
             if verbose>=2: print('[pca] >Warning: n_feat can not be reached because of the limitation of n_components (=%d). n_feat is reduced to %d.' %(self.n_components, n_feat))
 
         # Plot arrows and text
+        texts = []
         for i in range(0, n_feat):
             getfeat = topfeat['feature'].iloc[i]
             label = getfeat + ' (' + ('%g' %topfeat['loading'].iloc[i]) + ')'
             getcoef = coeff[getfeat].values
             # Set first PC vs second PC direction. Note that these are not neccarily the best loading.
-            xarrow = getcoef[PC[0]] * scale  # First PC in the x-axis direction
-            yarrow = getcoef[PC[1]] * scale  # Second PC in the y-axis direction
+            xarrow = getcoef[0] * scale  # First PC in the x-axis direction
+            yarrow = getcoef[1] * scale  # Second PC in the y-axis direction
             txtcolor = 'y' if topfeat['type'].iloc[i] == 'weak' else 'g'
 
             if d3:
-                # zarrow = getcoef[np.minimum(2,len(getcoef))] * scale
-                zarrow = getcoef[PC[2]] * scale
+                zarrow = getcoef[2] * scale
                 ax.quiver(mean_x, mean_y, mean_z, xarrow - mean_x, yarrow - mean_y, zarrow - mean_z, color=color_arrow, alpha=0.8, lw=2)
-                ax.text(xarrow * 1.11, yarrow * 1.11, zarrow * 1.11, label, color=txtcolor, ha='center', va='center')
+                texts.append(ax.text(xarrow, yarrow, zarrow, label, color=txtcolor, ha='center', va='center'))
             else:
-                ax.arrow(mean_x, mean_y, xarrow - mean_x, yarrow - mean_y, color=color_arrow, width=0.005, head_width=0.025 * scale, alpha=0.8)
-                ax.text(xarrow * 1.11, yarrow * 1.11, label, color=txtcolor, ha='center', va='center')
+                ax.arrow(mean_x, mean_y, xarrow - mean_x, yarrow - mean_y, color=color_arrow, alpha=0.8, width=0.002, head_width=0.1, head_length=0.1 * 1.1, length_includes_head=True)
+                texts.append(ax.text(xarrow, yarrow, label, color=txtcolor, fontdict=fontdict))
 
+        # Plot the adjusted text labels to prevent overlap
+        if len(texts)>0: adjust_text(texts)
         if visible: plt.show()
         return(fig, ax)
 
-    def biplot3d(self, y=None, n_feat=None, label=True, PC=[0, 1, 2], legend=True, SPE=False, hotellingt2=False, cmap='Set1', visible=True, figsize=(15, 10), alpha_transparency=1, title=None, gradient=None):
+    def biplot3d(self,
+                 y=None,
+                 n_feat=None,
+                 label=True,
+                 PC=[0, 1, 2],
+                 SPE=False,
+                 hotellingt2=False,
+                 alpha_transparency=1,
+                 gradient=None,
+                 color_arrow='r',
+                 fontdict={'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'},
+                 cmap='Set1',
+                 title=None,
+                 legend=True,
+                 figsize=(15, 10),
+                 visible=True,
+                 verbose=3):
         """Make biplot in 3d.
 
         Parameters
@@ -811,23 +910,34 @@ class pca():
             None: Ignore all labels (this will significanly speed up the scatterplot)
         PC : list, default : [0, 1, 2]
             Plot the selected Principal Components. Note that counting starts from 0. PC1=0, PC2=1, PC3=2, etc.
-        legend : Bool, default: True
-            Show the legend based on the unique y-labels.
         SPE : Bool, default: False
             Show the outliers based on SPE/DmodX method.
         hotellingt2 : Bool, default: False
             Show the outliers based on the hotelling T2 test.
-        visible : Bool, default: True
-            Visible status of the Figure. When False, figure is created on the background.
-        figsize : (int, int), optional, default: (15, 10)
-            (width, height) in inches.
         alpha_transparency : Float, default: None
             The alpha blending value, between 0 (transparent) and 1 (opaque).
-        title : str, (default: None)
-            Title of the figure.
         gradient : String, (default: None)
             Hex (ending) color for the gradient of the scatterplot colors.
             '#FFFFFF'
+        color_arrow : String, (default: 'r')
+            color for the arrow.
+            'r' (default)
+        fontdict : dict.
+            dictionary containing properties for the arrow font-text
+            {'weight': 'normal', 'size': 10, 'ha': 'center', 'va': 'center'}
+        cmap : String, optional, default: 'Set1'
+            Colormap. If set to None, no points are shown.
+        title : str, (default: None)
+            Title of the figure.
+        legend : Bool, default: True
+            Show the legend based on the unique y-labels.
+        figsize : (int, int), optional, default: (15, 10)
+            (width, height) in inches.
+        visible : Bool, default: True
+            Visible status of the Figure. When False, figure is created on the background.
+        Verbose : int (default : 3)
+            The higher the number, the more information is printed.
+            Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
 
         Returns
         -------
@@ -838,27 +948,48 @@ class pca():
             print('[pca] >Requires 3 PCs to make 3d plot. Try to use biplot() instead.')
             return None, None
 
-        fig, ax = self.biplot(y=y, n_feat=n_feat, d3=True, label=label, PC=PC, legend=legend, SPE=SPE, cmap=cmap, hotellingt2=hotellingt2, visible=visible, figsize=figsize, alpha_transparency=alpha_transparency, title=title, gradient=gradient)
+        fig, ax = self.biplot(y=y,
+                              n_feat=n_feat,
+                              d3=True,
+                              label=label,
+                              PC=PC,
+                              SPE=SPE,
+                              hotellingt2=hotellingt2,
+                              alpha_transparency=alpha_transparency,
+                              gradient=gradient,
+                              color_arrow=color_arrow,
+                              fontdict=fontdict,
+                              cmap=cmap,
+                              title=title,
+                              legend=legend,
+                              figsize=figsize,
+                              visible=visible,
+                              verbose=verbose)
 
         return(fig, ax)
 
     # Show explained variance plot
-    def plot(self, n_components=None, figsize=(15, 10), xsteps=None, visible=True, title=None, verbose=3):
-        """Scree together with explained variance.
+    def plot(self, n_components=None, xsteps=None, title=None, visible=True, figsize=(15, 10), verbose=3):
+        """Scree-plot together with explained variance.
 
         Parameters
         ----------
-        model : dict
-            model created by the fit() function.
+        n_components : int [0..1], optional
+            Number of PCs that are returned for the plot.
+            None: All PCs.
+        xsteps : int, optional
+            Set the number of xticklabels.
+        title : str, (default: None)
+            Title of the figure.
         visible : Bool, default: True
-            Visible status of the Figure. When False, figure is created on the background.
-        figsize : (float, float), optional, default: None
-            (width, height) in inches. If not provided, defaults to rcParams["figure.figsize"] = (15, 10)
+            Visible status of the Figure
+            True : Figure is shown.
+            False: Figure is created on the background.
+        figsize : (int, int)
+            (width, height) in inches.
         Verbose : int (default : 3)
             The higher the number, the more information is printed.
             Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
-        title : str, (default: None)
-            Title of the figure.
 
         Returns
         -------
@@ -919,18 +1050,18 @@ class pca():
 
         Description
         -----------
-        Normalize your data using the principal components.
-        As an example, suppose there is (technical) variation in the fist
-        component and you want that out. This function transforms the data using
-        the components that you want, e.g., starting from the 2nd pc, up to the
-        pc that contains at least 95% of the explained variance
+        Normalize your data using the variance seen in hte Principal Components. This allows to remove (technical)
+        variation in the data by normalizing out e.g., the 1st or 2nd etc component. This function transforms the
+        original data using the PCs that you want to normalize out. As an example, if you aim to remove the variation
+        seen in the 1st PC, the returned dataset will contain only the variance seen from the 2nd PC and more.
 
         Parameters
         ----------
         X : numpy array
             Data set.
-        n_components : float [0..1], optional
-            Number of PCs to keep based on the explained variance. The default is 1 (keeping all)
+        n_components : int [0..1], optional
+            Number of PCs that are returned for the plot.
+            None: All PCs.
         pcexclude : list of int, optional
             The PCs to exclude. The default is [1].
 
@@ -972,8 +1103,9 @@ class pca():
         ----------
         data : str, optional
             Name of the dataset 'sprinkler' or 'titanic' or 'student'.
-        verbose : int, optional
-            Print message to screen. The default is 3.
+        Verbose : int (default : 3)
+            The higher the number, the more information is printed.
+            Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace
 
         Returns
         -------
@@ -1263,10 +1395,11 @@ def import_example(data='titanic', verbose=3):
 
 # %%
 def _get_explained_variance(X, components):
-    '''Get the explained variance.
+    """Get the explained variance.
     Get the explained variance from the principal components of the
     data. This follows the method outlined in [1] section 3.4 (Adjusted Total
     Variance). For an alternate approach (not implemented here), see [2].
+
     Parameters
     ----------
     X : ndarray, shape (n_samples, n_features)
@@ -1274,6 +1407,7 @@ def _get_explained_variance(X, components):
         samples and features, respectively.
     components : array, shape (n_components, n_features)
         The (un-normalized) principle components. [1]
+
     Notes
     -----
     The variance ratio may not be computed. The main reason is that we
@@ -1281,14 +1415,12 @@ def _get_explained_variance(X, components):
     the components.
     Orthogonality is enforced in this case. Other variants exist that don't
     enforce this [2].
+
     References
     ----------
-    .. [1] Journal of Computational and Graphical Statistics, Volume 15, Number
-        2, Pages 265–286. DOI: 10.1198/106186006X113430
-    .. [2] Rodolphe Jenatton, Guillaume Obozinski, Francis Bach ; Proceedings
-        of the Thirteenth International Conference on Artificial Intelligence
-        and Statistics, PMLR 9:366-373, 2010.
-    '''
+        * Journal of Computational and Graphical Statistics, Volume 15, Number 2, Pages 265–286. DOI: 10.1198/106186006X113430.
+        * Rodolphe Jenatton, Guillaume Obozinski, Francis Bach ; Proceedings of the Thirteenth International Conference on Artificial Intelligence and Statistics, PMLR 9:366-373, 2010.
+    """
     # the number of samples
     n_samples = X.shape[0]
     n_components = components.shape[0]
